OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Dodano na popis pouzdanih poslužitelja",
    "Server is already in the list of trusted servers." : "Poslužitelj se već nalazi na popisu pouzdanih poslužitelja.",
    "No server to federate with found" : "Nije pronađen nijedan poslužitelj za udruživanje",
    "Could not add server" : "Poslužitelj nije dodan",
    "Trusted servers" : "Pouzdani poslužitelji",
    "Federation" : "Udruženje",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Udruženje vam omogućuje povezivanje s drugim pouzdanim poslužiteljima i razmjenu korisničkih imenika.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Udruženje vam omogućuje povezivanje s drugim pouzdanim poslužiteljima i razmjenu korisničkih imenika. Primjerice, može se koristiti za automatsko dovršavanje imena vanjskih korisnika za udruženo dijeljenje.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Udruženje vam omogućuje povezivanje s drugim pouzdanim poslužiteljima i razmjenu korisničkih imenika. Primjerice, može se upotrijebiti za automatsko dovršavanje imena vanjskih korisnika za udruženo dijeljenje. Za stvaranje udruženog dijeljenja nije potrebno dodati poslužitelj kao pouzdani poslužitelj.",
    "+ Add trusted server" : "+ Dodaj pouzdani poslužitelj",
    "Trusted server" : "Pouzdan poslužitelj",
    "Add" : "Dodaj"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
