OC.L10N.register(
    "federation",
    {
    "Added to the list of trusted servers" : "Agiuntu a sa lista de is serbidores seguros",
    "Server is already in the list of trusted servers." : "Su serbidore est giai in sa lista de is serbidores seguros.",
    "No server to federate with found" : "Perunu serbidore agatadu pro sa federatzione",
    "Could not add server" : "No at fatu a agiùnghere su serbidore",
    "Trusted servers" : "Serbidores seguros",
    "Federation" : "Federatzione",
    "Federation allows you to connect with other trusted servers to exchange the user directory." : "Sa federatzione cunsentit de si collegare a àteros serbidores seguros pro iscambiare sa cartella utente.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing." : "Sa federatzione permitit de si collegare a àteros serbidores seguros pro intrare in sa cartella utente. Pro esèmpiu, si podet impreare pro su cumpletamentu automàticu de utèntzias esternas pro cumpartziduras federadas.",
    "Federation allows you to connect with other trusted servers to exchange the user directory. For example this will be used to auto-complete external users for federated sharing. It is not necessary to add a server as trusted server in order to create a federated share." : "Sa federatzione permitit de si collegare a àteros serbidores seguros pro iscambiare sa cartella utente. Pro esèmpiu s'at a impreare pro su cumpletamentu automàticu de utèntzias esternas pro cumpartziduras federadas. Non serbit a agiùnghere unu serbidore comente seguru pro creare una cumpartzidura federada.",
    "+ Add trusted server" : "+ Agiunghe serbidore seguru",
    "Trusted server" : "Serbidore seguru",
    "Add" : "Agiunghe"
},
"nplurals=2; plural=(n != 1);");
